Documentation
¶
Index ¶
- func CreateTrustLineTx(sourceAccount txnbuild.Account, limit string, asset txnbuild.Asset, ...) (*txnbuild.Transaction, error)
- func GetMuxedAddress(accountID string, id uint64) (string, error)
- func GetNewAddress(secret string) (string, error)
- func NewRandSecret() (string, error)
- func PubKeyToAddr(publicKey []byte) (string, error)
- func SignTransaction(tx *txnbuild.Transaction, network string, secret ...string) (string, error)
- func TransferAssetTx(sourceAccount txnbuild.Account, toAddress, amount string, asset txnbuild.Asset, ...) (*txnbuild.Transaction, error)
- func ValidateAddress(address string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateTrustLineTx ¶
func CreateTrustLineTx(sourceAccount txnbuild.Account, limit string, asset txnbuild.Asset, baseFee, timeout int64, memo txnbuild.Memo) (*txnbuild.Transaction, error)
timeout: 0表示没时间限制
func GetNewAddress ¶
func NewRandSecret ¶
func PubKeyToAddr ¶
func SignTransaction ¶
func TransferAssetTx ¶
func ValidateAddress ¶
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package amount provides utilities for converting numbers to/from the format used internally to stellar-core.
|
Package amount provides utilities for converting numbers to/from the format used internally to stellar-core. |
|
Package network contains functions that deal with stellar network passphrases and IDs.
|
Package network contains functions that deal with stellar network passphrases and IDs. |
|
internal/crc16
Package crc16 is implementation according to CCITT standards.
|
Package crc16 is implementation according to CCITT standards. |
|
support
|
|
|
errors
Package errors provides the common infrastructure for managing errors.
|
Package errors provides the common infrastructure for managing errors. |
|
Package txnbuild implements transactions and operations on the Stellar network.
|
Package txnbuild implements transactions and operations on the Stellar network. |
|
Package xdr contains the generated code for parsing the xdr structures used for stellar.
|
Package xdr contains the generated code for parsing the xdr structures used for stellar. |
|
Package xdr implements the data representation portion of the External Data Representation (XDR) standard protocol as specified in RFC 4506 (obsoletes RFC 1832 and RFC 1014).
|
Package xdr implements the data representation portion of the External Data Representation (XDR) standard protocol as specified in RFC 4506 (obsoletes RFC 1832 and RFC 1014). |
Click to show internal directories.
Click to hide internal directories.